@@ -13,6 +13,8 @@ from .specific.ig import IntegratedGradientImage
 from .specific.gradcam import GradCAM, GradCAMPlus
 from .specific.cem import ContrastiveExplainer
 from .counterfactual.ce import CounterfactualExplainer
+from .specific.feature_visualization.visualizer import \
+    FeatureVisualizer, FeatureMapVisualizer
 
 __all__ = [
     "VisionExplainer",
@@ -25,4 +27,6 @@ __all__ = [
     "GradCAMPlus",
     "ContrastiveExplainer",
     "CounterfactualExplainer",
+    "FeatureVisualizer",
+    "FeatureMapVisualizer"
 ]
