@@ -5,8 +5,9 @@
 # For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 #
 from .specific.gradcam import GradCAM
-
+from .specific.ig import IntegratedGradient
 
 __all__ = [
     "GradCAM",
+    "IntegratedGradient"
 ]
