@@ -14,7 +14,7 @@ from omnixai.tests.explainers.tasks import TabularClassification
 
 class TestALE(unittest.TestCase):
 
-    def test(self):
+    def test_1(self):
         set_random_seed()
         base_folder = os.path.join(os.path.dirname(os.path.abspath(__file__)), "..")
         task = TabularClassification(base_folder).train_adult(num_training_samples=2000)
@@ -23,6 +23,19 @@ class TestALE(unittest.TestCase):
         explanations = explainer.explain()
         pprint.pprint(explanations.get_explanations())
 
+    def test_2(self):
+        set_random_seed()
+        task = TabularClassification().train_iris()
+        predict_function = lambda z: task.model.predict_proba(task.transform.transform(z))
+        explainer = ALE(training_data=task.train_data, predict_function=predict_function)
+
+        base_folder = os.path.dirname(os.path.abspath(__file__))
+        directory = f"{base_folder}/../../datasets/tmp"
+        explainer.save(directory=directory)
+        explainer = ALE.load(directory=directory)
+        explanations = explainer.explain()
+        pprint.pprint(explanations.get_explanations())
+
 
 if __name__ == "__main__":
     unittest.main()
